@@ -8,9 +8,9 @@
 TEST=$(txt2man -h 2> /dev/null)
 [ "$TEST" ] || { echo -e "\nYou need to install txt2man, from https://github.com/mvertes/txt2man.\n"; exit 1; }
 
-T2M_DATE="18 August 2019"
+T2M_DATE="16 April 2020"
 T2M_NAME=scrot
-T2M_VERSION=1.2
+T2M_VERSION=1.3
 T2M_LEVEL=1
 T2M_DESC="command line screen capture utility"
 
