@@ -8,6 +8,8 @@ Copyright 2010      Ibragimov Rinat <ibragimovrinat@mail.ru>
 Copyright 2017      Stoney Sauce <stoneysauce@gmail.com>
 Copyright 2019      Daniel T. Borelli <danieltborelli@gmail.com>
 Copyright 2019      Jade Auer <jade@trashwitch.dev>
+Copyright 2020      Hinigatsu <hinigatsu@protonmail.com>
+Copyright 2020      Sean Brennan <zettix1@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -49,7 +51,7 @@ main(int argc,
 
   init_parse_options(argc, argv);
 
-  init_x_and_imlib(NULL, 0);
+  init_x_and_imlib(opt.display, 0);
 
   if (!opt.output_file) {
     opt.output_file = gib_estrdup("%Y-%m-%d-%H%M%S_$wx$h_scrot.png");
@@ -64,7 +66,7 @@ main(int argc,
   else if (opt.select)
     image = scrot_sel_and_grab_image();
   else if (opt.autoselect)
-    image = gib_imlib_create_image_from_drawable(root, 0, opt.autoselect_x, opt.autoselect_y, opt.autoselect_w, opt.autoselect_h, 1);
+    image = scrot_grab_autoselect();
   else
   {
     scrot_do_delay();
@@ -345,18 +347,37 @@ scrot_sel_and_grab_image(void)
   GC gc;
   XGCValues gcval;
 
+  gcval.function = GXxor;
+  gcval.foreground = XWhitePixel(disp, 0);
+  gcval.background = XBlackPixel(disp, 0);
+  gcval.plane_mask = gcval.background ^ gcval.foreground;
+  gcval.subwindow_mode = IncludeInferiors;
+
+  if (opt.line_color != NULL) {
+    XColor clr_exact, clr_closest;
+    Status ret;
+
+    ret = XAllocNamedColor(disp, XDefaultColormap(disp, DefaultScreen(disp)),
+            opt.line_color, &clr_exact, &clr_closest);
+
+    if (ret == 0) {
+       free(opt.line_color);
+       fprintf(stderr, "Error allocate color:%s\n", strerror(BadColor));
+       exit(EXIT_FAILURE);
+    }
+
+    gcval.foreground = clr_exact.pixel;
+
+    free(opt.line_color);
+    opt.line_color = NULL;
+  }
+
   xfd = ConnectionNumber(disp);
   fdsize = xfd + 1;
 
   cur_cross = XCreateFontCursor(disp, XC_cross);
   cur_angle = XCreateFontCursor(disp, XC_lr_angle);
 
-  gcval.foreground = XWhitePixel(disp, 0);
-  gcval.function = GXxor;
-  gcval.background = XBlackPixel(disp, 0);
-  gcval.plane_mask = gcval.background ^ gcval.foreground;
-  gcval.subwindow_mode = IncludeInferiors;
-
   gc =
     XCreateGC(disp, root,
               GCFunction | GCForeground | GCBackground | GCSubwindowMode,
@@ -509,6 +530,20 @@ scrot_sel_and_grab_image(void)
   return im;
 }
 
+Imlib_Image
+scrot_grab_autoselect(void)
+{
+  Imlib_Image im = NULL;
+  int rx = opt.autoselect_x, ry = opt.autoselect_y, rw = opt.autoselect_w, rh = opt.autoselect_h;
+
+  scrot_do_delay();
+  scrot_nice_clip(&rx, &ry, &rw, &rh);
+  im = gib_imlib_create_image_from_drawable(root, 0, rx, ry, rw, rh, 1);
+  if (opt.pointer == 1)
+	  scrot_grab_mouse_pointer(im, rx, ry);
+  return im;
+}
+
 /* clip rectangle nicely */
 void
 scrot_nice_clip(int *rx, 
