@@ -11,6 +11,7 @@ Copyright 2017      Stoney Sauce <stoneysauce@gmail.com>
 Copyright 2019      Daniel Lublin <daniel@lublin.se>
 Copyright 2019      Daniel T. Borelli <danieltborelli@gmail.com>
 Copyright 2019      Jade Auer <jade@trashwitch.dev>
+Copyright 2020      Sean Brennan <zettix1@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -49,6 +50,8 @@ init_parse_options(int argc, char **argv)
    opt.overwrite = 0;
    opt.line_style = LineSolid;
    opt.line_width = 1;
+   opt.line_color = NULL;
+   opt.display = NULL;
 
    /* Parse the cmdline args */
    scrot_parse_option_array(argc, argv);
@@ -79,11 +82,12 @@ options_parse_required_number(char *str)
 static void
 options_parse_line(char *optarg)
 {
-   enum {STYLE = 0, WIDTH };
+   enum {STYLE = 0, WIDTH, COLOR };
 
    char *const token[] = {
       [STYLE] = "style",
       [WIDTH] = "width",
+      [COLOR] = "color",
       NULL
    };
 
@@ -129,6 +133,17 @@ options_parse_line(char *optarg)
             }
             break;
 
+         case COLOR:
+
+            if (value == NULL || *value == '\0') {
+               fprintf(stderr, "Missing value for "
+                     "suboption '%s'\n", token[COLOR]);
+               exit(EXIT_FAILURE);
+            }
+
+            opt.line_color = strdup(value);
+
+            break;
          default:
             fprintf(stderr, "No match found for token: '%s'\n", value);
             exit(EXIT_FAILURE);
@@ -142,7 +157,7 @@ options_parse_line(char *optarg)
 static void
 scrot_parse_option_array(int argc, char **argv)
 {
-   static char stropts[] = "a:ofpbcd:e:hmq:st:uv+:zn:l:";
+   static char stropts[] = "a:ofpbcd:e:hmq:st:uv+:zn:l:D:";
 
    static struct option lopts[] = {
       /* actions */
@@ -165,6 +180,7 @@ scrot_parse_option_array(int argc, char **argv)
       {"exec", 1, 0, 'e'},
       {"debug-level", 1, 0, '+'},
       {"autoselect", required_argument, 0, 'a'},
+      {"display", required_argument, 0, 'D'},
       {"note", required_argument, 0, 'n'},
       {"line", required_argument, 0, 'l'},
       {0, 0, 0, 0}
@@ -230,6 +246,9 @@ scrot_parse_option_array(int argc, char **argv)
         case 'a':
            options_parse_autoselect(optarg);
            break;
+        case 'D':
+           options_parse_display(optarg);
+           break;
         case 'n':
            options_parse_note(optarg);
            break;
@@ -318,6 +337,21 @@ options_parse_autoselect(char *optarg)
    }
 }
 
+void
+options_parse_display(char *optarg)
+{
+   size_t length = 0;
+   char *new_display;
+
+   length = strlen(optarg) + 1;
+   if (length > 256) {
+     length = 256;
+   }
+   new_display = gib_emalloc(length);
+   strncpy(new_display, optarg, length);
+   opt.display=new_display;
+}
+
 void
 options_parse_thumbnail(char *optarg)
 {
@@ -394,6 +428,7 @@ show_usage(void)
            "  current directory.\n" "  See man " SCROT_PACKAGE " for more details\n"
            "  -h, --help                display this help and exit\n"
            "  -v, --version             output version information and exit\n"
+           "  -D, --display             Set DISPLAY target other than current\n"
            "  -a, --autoselect          non-interactively choose a rectangle of x,y,w,h\n"
            "  -b, --border              When selecting a window, grab wm border too\n"
            "  -c, --count               show a countdown before taking the shot\n"
@@ -447,11 +482,13 @@ show_usage(void)
            "\n" "  SELECTION STYLE\n"
            "  When using --select you can indicate the style of the line with --line.\n"
            "  The following specifiers are recognised:\n"
-           "                  style=(solid,dash),width=(range 1 to 8)\n"
+           "                  style=(solid,dash),width=(range 1 to 8),color=\"value\"\n"
            "  The default style are:\n"
            "                  style=solid,width=1\n"
+           "  For the color you can use a name or a hexdecimal value.\n"
+           "                  color=\"red\" or color=\"#ff0000\"\n"
            "  Example:\n" "          " SCROT_PACKAGE
-           " --line style=dash,width=3 --select\n\n"
+           " --line style=dash,width=3,color=\"red\" --select\n\n"
            "\n" "  NOTE FORMAT\n"
            "  The following specifiers are recognised for the option --note\n"
            "                  -f 'FontName/size'\n"
