@@ -7,7 +7,7 @@ Copyright 2009      James Cameron <quozl@us.netrek.org>
 Copyright 2010      Ibragimov Rinat <ibragimovrinat@mail.ru>
 Copyright 2017      Stoney Sauce <stoneysauce@gmail.com>
 Copyright 2019      Daniel T. Borelli <danieltborelli@gmail.com>
-
+Copýright 2020      Sean Brennan <zettix1@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -52,9 +52,11 @@ struct __scrotoptions
    int overwrite;
    int line_style;
    int line_width;
+   char *line_color;
    char *output_file;
    char *thumb_file;
    char *exec;
+   char *display;
    char *note;
    int autoselect;
    int autoselect_x;
@@ -67,6 +69,7 @@ void init_parse_options(int argc, char **argv);
 char *name_thumbnail(char *name);
 void options_parse_thumbnail(char *optarg);
 void options_parse_autoselect(char *optarg);
+void options_parse_display(char *optarg);
 void options_parse_note(char *optarg);
 int  options_parse_required_number(char *str);
 extern scrotoptions opt;
